@@ -31,7 +31,11 @@ CKEDITOR.lang['el'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle		: 'Rich text editor, %1', // MISSING
+	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+
+	// ARIA descriptions.
+	toolbar	: 'Toolbar', // MISSING
+	editor	: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'HTML κώδικας',
@@ -68,12 +72,12 @@ CKEDITOR.lang['el'] =
 		flash			: 'Εισαγωγή Flash',
 		form			: 'Φόρμα',
 		checkbox		: 'Κουτί επιλογής',
-		radio		: 'Κουμπί Radio',
+		radio			: 'Κουμπί Radio',
 		textField		: 'Πεδίο κειμένου',
 		textarea		: 'Περιοχή κειμένου',
 		hiddenField		: 'Κρυφό πεδίο',
 		button			: 'Κουμπί',
-		select	: 'Πεδίο επιλογής',
+		select			: 'Πεδίο επιλογής',
 		imageButton		: 'Κουμπί εικόνας',
 		notSet			: '<χωρίς>',
 		id				: 'Id',
@@ -88,27 +92,42 @@ CKEDITOR.lang['el'] =
 		cssStyle		: 'Στύλ',
 		ok				: 'OK',
 		cancel			: 'Ακύρωση',
+		close			: 'Close', // MISSING
+		preview			: 'Preview', // MISSING
 		generalTab		: 'General', // MISSING
 		advancedTab		: 'Για προχωρημένους',
-		validateNumberFailed	: 'This value is not a number.', // MISSING
+		validateNumberFailed : 'This value is not a number.', // MISSING
 		confirmNewPage	: 'Any unsaved changes to this content will be lost. Are you sure you want to load new page?', // MISSING
 		confirmCancel	: 'Some of the options have been changed. Are you sure to close the dialog?', // MISSING
+		options			: 'Options', // MISSING
+		target			: 'Target', // MISSING
+		targetNew		: 'New Window (_blank)', // MISSING
+		targetTop		: 'Topmost Window (_top)', // MISSING
+		targetSelf		: 'Same Window (_self)', // MISSING
+		targetParent	: 'Parent Window (_parent)', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
 	},
 
+	contextmenu :
+	{
+		options : 'Context Menu Options' // MISSING
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'Εισαγωγή Ειδικού Συμβόλου',
-		title		: 'Επιλέξτε ένα Ειδικό Σύμβολο'
+		title		: 'Επιλέξτε ένα Ειδικό Σύμβολο',
+		options : 'Special Character Options' // MISSING
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Εισαγωγή/Μεταβολή Συνδέσμου (Link)',
+		other 		: '<άλλος>',
 		menu		: 'Μεταβολή Συνδέσμου (Link)',
 		title		: 'Σύνδεσμος (Link)',
 		info		: 'Link',
@@ -116,22 +135,17 @@ CKEDITOR.lang['el'] =
 		upload		: 'Αποστολή',
 		advanced	: 'Για προχωρημένους',
 		type		: 'Τύπος συνδέσμου (Link)',
+		toUrl		: 'URL', // MISSING
 		toAnchor	: 'Άγκυρα σε αυτή τη σελίδα',
 		toEmail		: 'E-Mail',
-		target		: 'Παράθυρο Στόχος (Target)',
-		targetNotSet	: '<χωρίς>',
-		targetFrame	: '<πλαίσιο>',
-		targetPopup	: '<παράθυρο popup>',
-		targetNew	: 'Νέο Παράθυρο (_blank)',
-		targetTop	: 'Ανώτατο Παράθυρο (_top)',
-		targetSelf	: 'Ίδιο Παράθυρο (_self)',
-		targetParent	: 'Γονικό Παράθυρο (_parent)',
+		targetFrame		: '<πλαίσιο>',
+		targetPopup		: '<παράθυρο popup>',
 		targetFrameName	: 'Όνομα πλαισίου στόχου',
 		targetPopupName	: 'Όνομα Popup Window',
 		popupFeatures	: 'Επιλογές Popup Window',
 		popupResizable	: 'Resizable', // MISSING
 		popupStatusBar	: 'Μπάρα Status',
-		popupLocationBar	: 'Μπάρα Τοποθεσίας',
+		popupLocationBar: 'Μπάρα Τοποθεσίας',
 		popupToolbar	: 'Μπάρα Εργαλείων',
 		popupMenuBar	: 'Μπάρα Menu',
 		popupFullScreen	: 'Ολόκληρη η Οθόνη (IE)',
@@ -143,7 +157,6 @@ CKEDITOR.lang['el'] =
 		popupTop		: 'Τοποθεσία Πάνω Άκρης',
 		id				: 'Id', // MISSING
 		langDir			: 'Κατεύθυνση κειμένου',
-		langDirNotSet	: '<χωρίς>',
 		langDirLTR		: 'Αριστερά προς Δεξιά (LTR)',
 		langDirRTL		: 'Δεξιά προς Αριστερά (RTL)',
 		acccessKey		: 'Συντόμευση (Access Key)',
@@ -176,6 +189,29 @@ CKEDITOR.lang['el'] =
 		errorName	: 'Παρακαλούμε εισάγετε όνομα άγκυρας'
 	},
 
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Numbered List Properties', // MISSING
+		bulletedTitle		: 'Bulleted List Properties', // MISSING
+		type				: 'Type', // MISSING
+		start				: 'Start', // MISSING
+		circle				: 'Circle', // MISSING
+		disc				: 'Disc', // MISSING
+		square				: 'Square', // MISSING
+		none				: 'None', // MISSING
+		notset				: '<not set>', // MISSING
+		armenian			: 'Armenian numbering', // MISSING
+		georgian			: 'Georgian numbering (an, ban, gan, etc.)', // MISSING
+		lowerRoman			: 'Lower Roman (i, ii, iii, iv, v, etc.)', // MISSING
+		upperRoman			: 'Upper Roman (I, II, III, IV, V, etc.)', // MISSING
+		lowerAlpha			: 'Lower Alpha (a, b, c, d, e, etc.)', // MISSING
+		upperAlpha			: 'Upper Alpha (A, B, C, D, E, etc.)', // MISSING
+		lowerGreek			: 'Lower Greek (alpha, beta, gamma, etc.)', // MISSING
+		decimal				: 'Decimal (1, 2, 3, etc.)', // MISSING
+		decimalLeadingZero	: 'Decimal leading zero (01, 02, 03, etc.)' // MISSING
+	},
+
 	// Find And Replace Dialog
 	findAndReplace :
 	{
@@ -203,13 +239,13 @@ CKEDITOR.lang['el'] =
 		columns		: 'Κολώνες',
 		border		: 'Μέγεθος Περιθωρίου',
 		align		: 'Στοίχιση',
-		alignNotSet	: '<χωρίς>',
 		alignLeft	: 'Αριστερά',
 		alignCenter	: 'Κέντρο',
 		alignRight	: 'Δεξιά',
 		width		: 'Πλάτος',
 		widthPx		: 'pixels',
 		widthPc		: '%',
+		widthUnit	: 'width unit', // MISSING
 		height		: 'Ύψος',
 		cellSpace	: 'Απόσταση κελιών',
 		cellPad		: 'Γέμισμα κελιών',
@@ -260,7 +296,7 @@ CKEDITOR.lang['el'] =
 			invalidHeight	: 'Cell height must be a number.', // MISSING
 			invalidRowSpan	: 'Rows span must be a whole number.', // MISSING
 			invalidColSpan	: 'Columns span must be a whole number.', // MISSING
-			chooseColor : 'Choose' // MISSING
+			chooseColor		: 'Choose' // MISSING
 		},
 
 		row :
@@ -307,13 +343,7 @@ CKEDITOR.lang['el'] =
 		menu		: 'Ιδιότητες φόρμας',
 		action		: 'Δράση',
 		method		: 'Μάθοδος',
-		encoding	: 'Encoding', // MISSING
-		target		: 'Παράθυρο Στόχος (Target)',
-		targetNotSet	: '<χωρίς>',
-		targetNew	: 'Νέο Παράθυρο (_blank)',
-		targetTop	: 'Ανώτατο Παράθυρο (_top)',
-		targetSelf	: 'Ίδιο Παράθυρο (_self)',
-		targetParent	: 'Γονικό Παράθυρο (_parent)'
+		encoding	: 'Encoding' // MISSING
 	},
 
 	// Select Field Dialog.
@@ -371,27 +401,31 @@ CKEDITOR.lang['el'] =
 		title		: 'Ιδιότητες Εικόνας',
 		titleButton	: 'Ιδιότητες κουμπιού εικόνας',
 		menu		: 'Ιδιότητες Εικόνας',
-		infoTab	: 'Πληροφορίες Εικόνας',
+		infoTab		: 'Πληροφορίες Εικόνας',
 		btnUpload	: 'Αποστολή στον Διακομιστή',
-		url		: 'URL',
-		upload	: 'Αποστολή',
-		alt		: 'Εναλλακτικό Κείμενο (ALT)',
+		upload		: 'Αποστολή',
+		alt			: 'Εναλλακτικό Κείμενο (ALT)',
 		width		: 'Πλάτος',
-		height	: 'Ύψος',
+		height		: 'Ύψος',
 		lockRatio	: 'Κλείδωμα Αναλογίας',
+		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Επαναφορά Αρχικού Μεγέθους',
-		border	: 'Περιθώριο',
-		hSpace	: 'Οριζόντιος Χώρος (HSpace)',
-		vSpace	: 'Κάθετος Χώρος (VSpace)',
+		border		: 'Περιθώριο',
+		hSpace		: 'Οριζόντιος Χώρος (HSpace)',
+		vSpace		: 'Κάθετος Χώρος (VSpace)',
 		align		: 'Ευθυγράμμιση (Align)',
 		alignLeft	: 'Αριστερά',
 		alignRight	: 'Δεξιά (Right)',
-		preview	: 'Προεπισκόπιση',
 		alertUrl	: 'Εισάγετε την τοποθεσία (URL) της εικόνας',
-		linkTab	: 'Σύνδεσμος',
+		linkTab		: 'Σύνδεσμος',
 		button2Img	: 'Do you want to transform the selected image button on a simple image?', // MISSING
 		img2Button	: 'Do you want to transform the selected image on a image button?', // MISSING
-		urlMissing : 'Image source URL is missing.' // MISSING
+		urlMissing	: 'Image source URL is missing.', // MISSING
+		validateWidth	: 'Width must be a whole number.', // MISSING
+		validateHeight	: 'Height must be a whole number.', // MISSING
+		validateBorder	: 'Border must be a whole number.', // MISSING
+		validateHSpace	: 'HSpace must be a whole number.', // MISSING
+		validateVSpace	: 'VSpace must be a whole number.' // MISSING
 	},
 
 	// Flash Dialog
@@ -399,51 +433,51 @@ CKEDITOR.lang['el'] =
 	{
 		properties		: 'Ιδιότητες Flash',
 		propertiesTab	: 'Properties', // MISSING
-		title		: 'Ιδιότητες flash',
-		chkPlay		: 'Αυτόματη έναρξη',
-		chkLoop		: 'Επανάληψη',
-		chkMenu		: 'Ενεργοποίηση Flash Menu',
-		chkFull		: 'Allow Fullscreen', // MISSING
- 		scale		: 'Κλίμακα',
+		title			: 'Ιδιότητες flash',
+		chkPlay			: 'Αυτόματη έναρξη',
+		chkLoop			: 'Επανάληψη',
+		chkMenu			: 'Ενεργοποίηση Flash Menu',
+		chkFull			: 'Allow Fullscreen', // MISSING
+ 		scale			: 'Κλίμακα',
 		scaleAll		: 'Εμφάνιση όλων',
 		scaleNoBorder	: 'Χωρίς όρια',
 		scaleFit		: 'Ακριβής εφαρμογή',
 		access			: 'Script Access', // MISSING
 		accessAlways	: 'Always', // MISSING
-		accessSameDomain	: 'Same domain', // MISSING
-		accessNever	: 'Never', // MISSING
-		align		: 'Ευθυγράμμιση (Align)',
-		alignLeft	: 'Αριστερά',
-		alignAbsBottom: 'Απόλυτα Κάτω (Abs Bottom)',
-		alignAbsMiddle: 'Απόλυτα στη Μέση (Abs Middle)',
+		accessSameDomain: 'Same domain', // MISSING
+		accessNever		: 'Never', // MISSING
+		align			: 'Ευθυγράμμιση (Align)',
+		alignLeft		: 'Αριστερά',
+		alignAbsBottom	: 'Απόλυτα Κάτω (Abs Bottom)',
+		alignAbsMiddle	: 'Απόλυτα στη Μέση (Abs Middle)',
 		alignBaseline	: 'Γραμμή Βάσης (Baseline)',
-		alignBottom	: 'Κάτω (Bottom)',
-		alignMiddle	: 'Μέση (Middle)',
-		alignRight	: 'Δεξιά (Right)',
+		alignBottom		: 'Κάτω (Bottom)',
+		alignMiddle		: 'Μέση (Middle)',
+		alignRight		: 'Δεξιά (Right)',
 		alignTextTop	: 'Κορυφή Κειμένου (Text Top)',
-		alignTop	: 'Πάνω (Top)',
-		quality		: 'Quality', // MISSING
-		qualityBest		 : 'Best', // MISSING
-		qualityHigh		 : 'High', // MISSING
-		qualityAutoHigh	 : 'Auto High', // MISSING
-		qualityMedium	 : 'Medium', // MISSING
-		qualityAutoLow	 : 'Auto Low', // MISSING
-		qualityLow		 : 'Low', // MISSING
-		windowModeWindow	 : 'Window', // MISSING
-		windowModeOpaque	 : 'Opaque', // MISSING
-		windowModeTransparent	 : 'Transparent', // MISSING
-		windowMode	: 'Window mode', // MISSING
-		flashvars	: 'Variables for Flash', // MISSING
-		bgcolor	: 'Χρώμα Υποβάθρου',
-		width	: 'Πλάτος',
-		height	: 'Ύψος',
-		hSpace	: 'Οριζόντιος Χώρος (HSpace)',
-		vSpace	: 'Κάθετος Χώρος (VSpace)',
-		validateSrc : 'Εισάγετε την τοποθεσία (URL) του υπερσυνδέσμου (Link)',
-		validateWidth : 'Width must be a number.', // MISSING
-		validateHeight : 'Height must be a number.', // MISSING
-		validateHSpace : 'HSpace must be a number.', // MISSING
-		validateVSpace : 'VSpace must be a number.' // MISSING
+		alignTop		: 'Πάνω (Top)',
+		quality			: 'Quality', // MISSING
+		qualityBest		: 'Best', // MISSING
+		qualityHigh		: 'High', // MISSING
+		qualityAutoHigh	: 'Auto High', // MISSING
+		qualityMedium	: 'Medium', // MISSING
+		qualityAutoLow	: 'Auto Low', // MISSING
+		qualityLow		: 'Low', // MISSING
+		windowModeWindow: 'Window', // MISSING
+		windowModeOpaque: 'Opaque', // MISSING
+		windowModeTransparent : 'Transparent', // MISSING
+		windowMode		: 'Window mode', // MISSING
+		flashvars		: 'Variables for Flash', // MISSING
+		bgcolor			: 'Χρώμα Υποβάθρου',
+		width			: 'Πλάτος',
+		height			: 'Ύψος',
+		hSpace			: 'Οριζόντιος Χώρος (HSpace)',
+		vSpace			: 'Κάθετος Χώρος (VSpace)',
+		validateSrc		: 'Εισάγετε την τοποθεσία (URL) του υπερσυνδέσμου (Link)',
+		validateWidth	: 'Width must be a number.', // MISSING
+		validateHeight	: 'Height must be a number.', // MISSING
+		validateHSpace	: 'HSpace must be a number.', // MISSING
+		validateVSpace	: 'VSpace must be a number.' // MISSING
 	},
 
 	// Speller Pages Dialog
@@ -472,90 +506,91 @@ CKEDITOR.lang['el'] =
 	smiley :
 	{
 		toolbar	: 'Smiley',
-		title	: 'Επιλέξτε ένα Smiley'
+		title	: 'Επιλέξτε ένα Smiley',
+		options : 'Smiley Options' // MISSING
 	},
 
 	elementsPath :
 	{
+		eleLabel : 'Elements path', // MISSING
 		eleTitle : '%1 element' // MISSING
 	},
 
-	numberedlist : 'Λίστα με Αριθμούς',
-	bulletedlist : 'Λίστα με Bullets',
-	indent : 'Αύξηση Εσοχής',
-	outdent : 'Μείωση Εσοχής',
+	numberedlist	: 'Λίστα με Αριθμούς',
+	bulletedlist	: 'Λίστα με Bullets',
+	indent			: 'Αύξηση Εσοχής',
+	outdent			: 'Μείωση Εσοχής',
 
 	justify :
 	{
-		left : 'Στοίχιση Αριστερά',
-		center : 'Στοίχιση στο Κέντρο',
-		right : 'Στοίχιση Δεξιά',
-		block : 'Πλήρης Στοίχιση (Block)'
+		left	: 'Στοίχιση Αριστερά',
+		center	: 'Στοίχιση στο Κέντρο',
+		right	: 'Στοίχιση Δεξιά',
+		block	: 'Πλήρης Στοίχιση (Block)'
 	},
 
-	blockquote : 'Blockquote', // MISSING
+	blockquote : 'Block Quote', // MISSING
 
 	clipboard :
 	{
 		title		: 'Επικόλληση',
-		cutError	: 'Οι ρυθμίσεις ασφαλείας του φυλλομετρητή σας δεν επιτρέπουν την επιλεγμένη εργασία αποκοπής. Χρησιμοποιείστε το πληκτρολόγιο (Ctrl+X).',
-		copyError	: 'Οι ρυθμίσεις ασφαλείας του φυλλομετρητή σας δεν επιτρέπουν την επιλεγμένη εργασία αντιγραφής. Χρησιμοποιείστε το πληκτρολόγιο (Ctrl+C).',
-		pasteMsg	: 'Παρακαλώ επικολήστε στο ακόλουθο κουτί χρησιμοποιόντας το πληκτρολόγιο (<STRONG>Ctrl+V</STRONG>) και πατήστε <STRONG>OK</STRONG>.',
-		securityMsg	: 'Because of your browser security settings, the editor is not able to access your clipboard data directly. You are required to paste it again in this window.' // MISSING
+		cutError	: 'Οι ρυθμίσεις ασφαλείας του φυλλομετρητή σας δεν επιτρέπουν την επιλεγμένη εργασία αποκοπής. Χρησιμοποιείστε το πληκτρολόγιο (Ctrl/Cmd+X).',
+		copyError	: 'Οι ρυθμίσεις ασφαλείας του φυλλομετρητή σας δεν επιτρέπουν την επιλεγμένη εργασία αντιγραφής. Χρησιμοποιείστε το πληκτρολόγιο (Ctrl/Cmd+C).',
+		pasteMsg	: 'Παρακαλώ επικολήστε στο ακόλουθο κουτί χρησιμοποιόντας το πληκτρολόγιο (<STRONG>Ctrl/Cmd+V</STRONG>) και πατήστε <STRONG>OK</STRONG>.',
+		securityMsg	: 'Because of your browser security settings, the editor is not able to access your clipboard data directly. You are required to paste it again in this window.', // MISSING
+		pasteArea	: 'Paste Area' // MISSING
 	},
 
 	pastefromword :
 	{
-		confirmCleanup : 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
-		toolbar : 'Επικόλληση από το Word',
-		title : 'Επικόλληση από το Word',
-		error : 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		confirmCleanup	: 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
+		toolbar			: 'Επικόλληση από το Word',
+		title			: 'Επικόλληση από το Word',
+		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
 	},
 
 	pasteText :
 	{
-		button : 'Επικόλληση ως Απλό Κείμενο',
-		title : 'Επικόλληση ως Απλό Κείμενο'
+		button	: 'Επικόλληση ως Απλό Κείμενο',
+		title	: 'Επικόλληση ως Απλό Κείμενο'
 	},
 
 	templates :
 	{
-		button : 'Πρότυπα',
-		title : 'Πρότυπα περιεχομένου',
-		insertOption: 'Αντικατάσταση υπάρχοντων περιεχομένων',
-		selectPromptMsg: 'Παρακαλώ επιλέξτε πρότυπο για εισαγωγή στο πρόγραμμα<br>(τα υπάρχοντα περιεχόμενα θα χαθούν):',
-		emptyListMsg : '(Δεν έχουν καθοριστεί πρότυπα)'
+		button			: 'Πρότυπα',
+		title			: 'Πρότυπα περιεχομένου',
+		options : 'Template Options', // MISSING
+		insertOption	: 'Αντικατάσταση υπάρχοντων περιεχομένων',
+		selectPromptMsg	: 'Παρακαλώ επιλέξτε πρότυπο για εισαγωγή στο πρόγραμμα<br>(τα υπάρχοντα περιεχόμενα θα χαθούν):',
+		emptyListMsg	: '(Δεν έχουν καθοριστεί πρότυπα)'
 	},
 
 	showBlocks : 'Show Blocks', // MISSING
 
 	stylesCombo :
 	{
-		label : 'Στυλ',
-		voiceLabel : 'Styles', // MISSING
-		panelVoiceLabel : 'Select a style', // MISSING
-		panelTitle1 : 'Block Styles', // MISSING
-		panelTitle2 : 'Inline Styles', // MISSING
-		panelTitle3 : 'Object Styles' // MISSING
+		label		: 'Στυλ',
+		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle1	: 'Block Styles', // MISSING
+		panelTitle2	: 'Inline Styles', // MISSING
+		panelTitle3	: 'Object Styles' // MISSING
 	},
 
 	format :
 	{
-		label : 'Μορφή Γραμματοσειράς',
-		voiceLabel : 'Format', // MISSING
-		panelTitle : 'Μορφή Γραμματοσειράς',
-		panelVoiceLabel : 'Select a paragraph format', // MISSING
+		label		: 'Μορφή Γραμματοσειράς',
+		panelTitle	: 'Μορφή Γραμματοσειράς',
 
-		tag_p : 'Κανονικό',
-		tag_pre : 'Μορφοποιημένο',
-		tag_address : 'Διεύθυνση',
-		tag_h1 : 'Επικεφαλίδα 1',
-		tag_h2 : 'Επικεφαλίδα 2',
-		tag_h3 : 'Επικεφαλίδα 3',
-		tag_h4 : 'Επικεφαλίδα 4',
-		tag_h5 : 'Επικεφαλίδα 5',
-		tag_h6 : 'Επικεφαλίδα 6',
-		tag_div : 'Normal (DIV)' // MISSING
+		tag_p		: 'Κανονικό',
+		tag_pre		: 'Μορφοποιημένο',
+		tag_address	: 'Διεύθυνση',
+		tag_h1		: 'Επικεφαλίδα 1',
+		tag_h2		: 'Επικεφαλίδα 2',
+		tag_h3		: 'Επικεφαλίδα 3',
+		tag_h4		: 'Επικεφαλίδα 4',
+		tag_h5		: 'Επικεφαλίδα 5',
+		tag_h6		: 'Επικεφαλίδα 6',
+		tag_div		: 'Normal (DIV)' // MISSING
 	},
 
 	div :
@@ -577,26 +612,25 @@ CKEDITOR.lang['el'] =
 
 	font :
 	{
-		label : 'Γραμματοσειρά',
-		voiceLabel : 'Font', // MISSING
-		panelTitle : 'Γραμματοσειρά',
-		panelVoiceLabel : 'Select a font' // MISSING
+		label		: 'Γραμματοσειρά',
+		voiceLabel	: 'Font', // MISSING
+		panelTitle	: 'Γραμματοσειρά'
 	},
 
 	fontSize :
 	{
-		label : 'Μέγεθος',
-		voiceLabel : 'Font Size', // MISSING
-		panelTitle : 'Μέγεθος',
-		panelVoiceLabel : 'Select a font size' // MISSING
+		label		: 'Μέγεθος',
+		voiceLabel	: 'Font Size', // MISSING
+		panelTitle	: 'Μέγεθος'
 	},
 
 	colorButton :
 	{
-		textColorTitle : 'Χρώμα Γραμμάτων',
-		bgColorTitle : 'Χρώμα Υποβάθρου',
-		auto : 'Αυτόματο',
-		more : 'Περισσότερα χρώματα...'
+		textColorTitle	: 'Χρώμα Γραμμάτων',
+		bgColorTitle	: 'Χρώμα Υποβάθρου',
+		panelTitle		: 'Colors', // MISSING
+		auto			: 'Αυτόματο',
+		more			: 'Περισσότερα χρώματα...'
 	},
 
 	colors :
@@ -645,30 +679,45 @@ CKEDITOR.lang['el'] =
 
 	scayt :
 	{
-		title : 'Spell Check As You Type', // MISSING
-		enable : 'Enable SCAYT', // MISSING
-		disable : 'Disable SCAYT', // MISSING
-		about : 'About SCAYT', // MISSING
-		toggle : 'Toggle SCAYT', // MISSING
-		options : 'Options', // MISSING
-		langs : 'Languages', // MISSING
-		moreSuggestions : 'More suggestions', // MISSING
-		ignore : 'Ignore', // MISSING
-		ignoreAll : 'Ignore All', // MISSING
-		addWord : 'Add Word', // MISSING
-		emptyDic : 'Dictionary name should not be empty.', // MISSING
-		optionsTab : 'Options', // MISSING
-		languagesTab : 'Languages', // MISSING
-		dictionariesTab : 'Dictionaries', // MISSING
-		aboutTab : 'About' // MISSING
+		title			: 'Spell Check As You Type', // MISSING
+		opera_title		: 'Not supported by Opera', // MISSING
+		enable			: 'Enable SCAYT', // MISSING
+		disable			: 'Disable SCAYT', // MISSING
+		about			: 'About SCAYT', // MISSING
+		toggle			: 'Toggle SCAYT', // MISSING
+		options			: 'Options', // MISSING
+		langs			: 'Languages', // MISSING
+		moreSuggestions	: 'More suggestions', // MISSING
+		ignore			: 'Ignore', // MISSING
+		ignoreAll		: 'Ignore All', // MISSING
+		addWord			: 'Add Word', // MISSING
+		emptyDic		: 'Dictionary name should not be empty.', // MISSING
+
+		optionsTab		: 'Options', // MISSING
+		allCaps			: 'Ignore All-Caps Words', // MISSING
+		ignoreDomainNames : 'Ignore Domain Names', // MISSING
+		mixedCase		: 'Ignore Words with Mixed Case', // MISSING
+		mixedWithDigits	: 'Ignore Words with Numbers', // MISSING
+
+		languagesTab	: 'Languages', // MISSING
+
+		dictionariesTab	: 'Dictionaries', // MISSING
+		dic_field_name	: 'Dictionary name', // MISSING
+		dic_create		: 'Create', // MISSING
+		dic_restore		: 'Restore', // MISSING
+		dic_delete		: 'Delete', // MISSING
+		dic_rename		: 'Rename', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type it\'s name and click the Restore button.', // MISSING
+
+		aboutTab		: 'About' // MISSING
 	},
 
 	about :
 	{
-		title : 'About CKEditor', // MISSING
-		dlgTitle : 'About CKEditor', // MISSING
-		moreInfo : 'For licensing information please visit our web site:', // MISSING
-		copy : 'Copyright &copy; $1. All rights reserved.' // MISSING
+		title		: 'About CKEditor', // MISSING
+		dlgTitle	: 'About CKEditor', // MISSING
+		moreInfo	: 'For licensing information please visit our web site:', // MISSING
+		copy		: 'Copyright &copy; $1. All rights reserved.' // MISSING
 	},
 
 	maximize : 'Maximize', // MISSING
@@ -676,22 +725,23 @@ CKEDITOR.lang['el'] =
 
 	fakeobjects :
 	{
-		anchor : 'Anchor', // MISSING
-		flash : 'Flash Animation', // MISSING
-		div : 'Page Break', // MISSING
-		unknown : 'Unknown Object' // MISSING
+		anchor	: 'Anchor', // MISSING
+		flash	: 'Flash Animation', // MISSING
+		div		: 'Page Break', // MISSING
+		unknown	: 'Unknown Object' // MISSING
 	},
 
 	resize : 'Drag to resize', // MISSING
 
 	colordialog :
 	{
-		title : 'Select color', // MISSING
-		highlight : 'Highlight', // MISSING
-		selected : 'Selected', // MISSING
-		clear : 'Clear' // MISSING
+		title		: 'Select color', // MISSING
+		options	:	'Color Options', // MISSING
+		highlight	: 'Highlight', // MISSING
+		selected	: 'Selected Color', // MISSING
+		clear		: 'Clear' // MISSING
 	},
 
-	toolbarCollapse : 'Collapse Toolbar', // MISSING
-	toolbarExpand : 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Collapse Toolbar', // MISSING
+	toolbarExpand	: 'Expand Toolbar' // MISSING
 };
