@@ -31,7 +31,11 @@ CKEDITOR.lang['sl'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle		: 'Rich text editor, %1', // MISSING
+	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+
+	// ARIA descriptions.
+	toolbar	: 'Toolbar', // MISSING
+	editor	: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'Izvorna koda',
@@ -68,12 +72,12 @@ CKEDITOR.lang['sl'] =
 		flash			: 'Flash',
 		form			: 'Obrazec',
 		checkbox		: 'Potrditveno polje',
-		radio		: 'Izbirno polje',
+		radio			: 'Izbirno polje',
 		textField		: 'Vnosno polje',
 		textarea		: 'Vnosno območje',
 		hiddenField		: 'Skrito polje',
 		button			: 'Gumb',
-		select	: 'Spustni seznam',
+		select			: 'Spustni seznam',
 		imageButton		: 'Gumb s sliko',
 		notSet			: '<ni postavljen>',
 		id				: 'Id',
@@ -88,27 +92,42 @@ CKEDITOR.lang['sl'] =
 		cssStyle		: 'Slog',
 		ok				: 'V redu',
 		cancel			: 'Prekliči',
-		generalTab		: 'General', // MISSING
+		close			: 'Close', // MISSING
+		preview			: 'Preview', // MISSING
+		generalTab		: 'Splošno',
 		advancedTab		: 'Napredno',
-		validateNumberFailed	: 'This value is not a number.', // MISSING
-		confirmNewPage	: 'Any unsaved changes to this content will be lost. Are you sure you want to load new page?', // MISSING
-		confirmCancel	: 'Some of the options have been changed. Are you sure to close the dialog?', // MISSING
+		validateNumberFailed : 'Ta vrednost ni število.',
+		confirmNewPage	: 'Vse neshranjene spremembe te vsebine bodo izgubljene. Ali gotovo želiš naložiti novo stran?',
+		confirmCancel	: 'Nekaj možnosti je bilo spremenjenih. Ali gotovo želiš zapreti okno?',
+		options			: 'Options', // MISSING
+		target			: 'Target', // MISSING
+		targetNew		: 'New Window (_blank)', // MISSING
+		targetTop		: 'Topmost Window (_top)', // MISSING
+		targetSelf		: 'Same Window (_self)', // MISSING
+		targetParent	: 'Parent Window (_parent)', // MISSING
 
 		// Put the voice-only part of the label in the span.
-		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
+		unavailable		: '%1<span class="cke_accessibility">, nedosegljiv</span>'
+	},
+
+	contextmenu :
+	{
+		options : 'Context Menu Options' // MISSING
 	},
 
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'Vstavi posebni znak',
-		title		: 'Izberi posebni znak'
+		title		: 'Izberi posebni znak',
+		options : 'Special Character Options' // MISSING
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Vstavi/uredi povezavo',
+		other 		: '<drug>',
 		menu		: 'Uredi povezavo',
 		title		: 'Povezava',
 		info		: 'Podatki o povezavi',
@@ -116,22 +135,17 @@ CKEDITOR.lang['sl'] =
 		upload		: 'Prenesi',
 		advanced	: 'Napredno',
 		type		: 'Vrsta povezave',
+		toUrl		: 'URL', // MISSING
 		toAnchor	: 'Zaznamek na tej strani',
 		toEmail		: 'Elektronski naslov',
-		target		: 'Cilj',
-		targetNotSet	: '<ni postavljen>',
-		targetFrame	: '<okvir>',
-		targetPopup	: '<pojavno okno>',
-		targetNew	: 'Novo okno (_blank)',
-		targetTop	: 'Najvišje okno (_top)',
-		targetSelf	: 'Isto okno (_self)',
-		targetParent	: 'Starševsko okno (_parent)',
+		targetFrame		: '<okvir>',
+		targetPopup		: '<pojavno okno>',
 		targetFrameName	: 'Ime ciljnega okvirja',
 		targetPopupName	: 'Ime pojavnega okna',
 		popupFeatures	: 'Značilnosti pojavnega okna',
-		popupResizable	: 'Resizable', // MISSING
+		popupResizable	: 'Spremenljive velikosti',
 		popupStatusBar	: 'Vrstica stanja',
-		popupLocationBar	: 'Naslovna vrstica',
+		popupLocationBar: 'Naslovna vrstica',
 		popupToolbar	: 'Orodna vrstica',
 		popupMenuBar	: 'Menijska vrstica',
 		popupFullScreen	: 'Celozaslonska slika (IE)',
@@ -141,9 +155,8 @@ CKEDITOR.lang['sl'] =
 		popupLeft		: 'Lega levo',
 		popupHeight		: 'Višina',
 		popupTop		: 'Lega na vrhu',
-		id				: 'Id', // MISSING
+		id				: 'Id',
 		langDir			: 'Smer jezika',
-		langDirNotSet	: '<ni postavljen>',
 		langDirLTR		: 'Od leve proti desni (LTR)',
 		langDirRTL		: 'Od desne proti levi (RTL)',
 		acccessKey		: 'Vstopno geslo',
@@ -176,6 +189,29 @@ CKEDITOR.lang['sl'] =
 		errorName	: 'Prosim vnesite ime zaznamka'
 	},
 
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Numbered List Properties', // MISSING
+		bulletedTitle		: 'Bulleted List Properties', // MISSING
+		type				: 'Type', // MISSING
+		start				: 'Start', // MISSING
+		circle				: 'Circle', // MISSING
+		disc				: 'Disc', // MISSING
+		square				: 'Square', // MISSING
+		none				: 'None', // MISSING
+		notset				: '<not set>', // MISSING
+		armenian			: 'Armenian numbering', // MISSING
+		georgian			: 'Georgian numbering (an, ban, gan, etc.)', // MISSING
+		lowerRoman			: 'Lower Roman (i, ii, iii, iv, v, etc.)', // MISSING
+		upperRoman			: 'Upper Roman (I, II, III, IV, V, etc.)', // MISSING
+		lowerAlpha			: 'Lower Alpha (a, b, c, d, e, etc.)', // MISSING
+		upperAlpha			: 'Upper Alpha (A, B, C, D, E, etc.)', // MISSING
+		lowerGreek			: 'Lower Greek (alpha, beta, gamma, etc.)', // MISSING
+		decimal				: 'Decimal (1, 2, 3, etc.)', // MISSING
+		decimalLeadingZero	: 'Decimal leading zero (01, 02, 03, etc.)' // MISSING
+	},
+
 	// Find And Replace Dialog
 	findAndReplace :
 	{
@@ -187,9 +223,9 @@ CKEDITOR.lang['sl'] =
 		notFoundMsg			: 'Navedeno besedilo ni bilo najdeno.',
 		matchCase			: 'Razlikuj velike in male črke',
 		matchWord			: 'Samo cele besede',
-		matchCyclic			: 'Match cyclic', // MISSING
+		matchCyclic			: 'Primerjaj znake v cirilici',
 		replaceAll			: 'Zamenjaj vse',
-		replaceSuccessMsg	: '%1 occurrence(s) replaced.' // MISSING
+		replaceSuccessMsg	: '%1 pojavitev je bilo zamenjano.'
 	},
 
 	// Table Dialog
@@ -203,30 +239,30 @@ CKEDITOR.lang['sl'] =
 		columns		: 'Stolpci',
 		border		: 'Velikost obrobe',
 		align		: 'Poravnava',
-		alignNotSet	: '<Ni nastavljeno>',
 		alignLeft	: 'Levo',
 		alignCenter	: 'Sredinsko',
 		alignRight	: 'Desno',
 		width		: 'Širina',
 		widthPx		: 'pik',
 		widthPc		: 'procentov',
+		widthUnit	: 'width unit', // MISSING
 		height		: 'Višina',
 		cellSpace	: 'Razmik med celicami',
 		cellPad		: 'Polnilo med celicami',
 		caption		: 'Naslov',
 		summary		: 'Povzetek',
-		headers		: 'Headers', // MISSING
-		headersNone		: 'None', // MISSING
-		headersColumn	: 'First column', // MISSING
-		headersRow		: 'First Row', // MISSING
-		headersBoth		: 'Both', // MISSING
-		invalidRows		: 'Number of rows must be a number greater than 0.', // MISSING
-		invalidCols		: 'Number of columns must be a number greater than 0.', // MISSING
-		invalidBorder	: 'Border size must be a number.', // MISSING
-		invalidWidth	: 'Table width must be a number.', // MISSING
-		invalidHeight	: 'Table height must be a number.', // MISSING
-		invalidCellSpacing	: 'Cell spacing must be a number.', // MISSING
-		invalidCellPadding	: 'Cell padding must be a number.', // MISSING
+		headers		: 'Glave',
+		headersNone		: 'Brez',
+		headersColumn	: 'Prvi stolpec',
+		headersRow		: 'Prva vrstica',
+		headersBoth		: 'Oboje',
+		invalidRows		: 'Število vrstic mora biti večje od 0.',
+		invalidCols		: 'Število stolpcev mora biti večje od 0.',
+		invalidBorder	: 'Širina obrobe mora biti število.',
+		invalidWidth	: 'Širina tabele mora biti število.',
+		invalidHeight	: 'Višina tabele mora biti število.',
+		invalidCellSpacing	: 'Razmik med celicami mora biti število.',
+		invalidCellPadding	: 'Zamik celic mora biti število',
 
 		cell :
 		{
@@ -239,28 +275,28 @@ CKEDITOR.lang['sl'] =
 			mergeDown		: 'Druži navzdol',
 			splitHorizontal	: 'Razdeli celico vodoravno',
 			splitVertical	: 'Razdeli celico navpično',
-			title			: 'Cell Properties', // MISSING
-			cellType		: 'Cell Type', // MISSING
-			rowSpan			: 'Rows Span', // MISSING
-			colSpan			: 'Columns Span', // MISSING
-			wordWrap		: 'Word Wrap', // MISSING
-			hAlign			: 'Horizontal Alignment', // MISSING
-			vAlign			: 'Vertical Alignment', // MISSING
-			alignTop		: 'Top', // MISSING
-			alignMiddle		: 'Middle', // MISSING
-			alignBottom		: 'Bottom', // MISSING
-			alignBaseline	: 'Baseline', // MISSING
-			bgColor			: 'Background Color', // MISSING
-			borderColor		: 'Border Color', // MISSING
-			data			: 'Data', // MISSING
-			header			: 'Header', // MISSING
-			yes				: 'Yes', // MISSING
-			no				: 'No', // MISSING
-			invalidWidth	: 'Cell width must be a number.', // MISSING
-			invalidHeight	: 'Cell height must be a number.', // MISSING
-			invalidRowSpan	: 'Rows span must be a whole number.', // MISSING
-			invalidColSpan	: 'Columns span must be a whole number.', // MISSING
-			chooseColor : 'Choose' // MISSING
+			title			: 'Lastnosti celice',
+			cellType		: 'Vrsta celice',
+			rowSpan			: 'Razpon vrstic',
+			colSpan			: 'Razpon stolpcev',
+			wordWrap		: 'Prelom besedila',
+			hAlign			: 'Vodoravna poravnava',
+			vAlign			: 'Navpična poravnava',
+			alignTop		: 'Vrh',
+			alignMiddle		: 'Sredina',
+			alignBottom		: 'Dno',
+			alignBaseline	: 'Osnovnica',
+			bgColor			: 'Barva ozadja',
+			borderColor		: 'Barva obrobe',
+			data			: 'Podatki',
+			header			: 'Glava',
+			yes				: 'Da',
+			no				: 'Ne',
+			invalidWidth	: 'Širina celice mora biti število.',
+			invalidHeight	: 'Višina celice mora biti število.',
+			invalidRowSpan	: 'Razpon vrstic mora biti celo število.',
+			invalidColSpan	: 'Razpon stolpcev mora biti celo število.',
+			chooseColor		: 'Izberi'
 		},
 
 		row :
@@ -307,13 +343,7 @@ CKEDITOR.lang['sl'] =
 		menu		: 'Lastnosti obrazca',
 		action		: 'Akcija',
 		method		: 'Metoda',
-		encoding	: 'Encoding', // MISSING
-		target		: 'Cilj',
-		targetNotSet	: '<ni postavljen>',
-		targetNew	: 'Novo okno (_blank)',
-		targetTop	: 'Najvišje okno (_top)',
-		targetSelf	: 'Isto okno (_self)',
-		targetParent	: 'Starševsko okno (_parent)'
+		encoding	: 'Kodiranje znakov'
 	},
 
 	// Select Field Dialog.
@@ -371,88 +401,92 @@ CKEDITOR.lang['sl'] =
 		title		: 'Lastnosti slike',
 		titleButton	: 'Lastnosti gumba s sliko',
 		menu		: 'Lastnosti slike',
-		infoTab	: 'Podatki o sliki',
+		infoTab		: 'Podatki o sliki',
 		btnUpload	: 'Pošlji na strežnik',
-		url		: 'URL',
-		upload	: 'Pošlji',
-		alt		: 'Nadomestno besedilo',
+		upload		: 'Pošlji',
+		alt			: 'Nadomestno besedilo',
 		width		: 'Širina',
-		height	: 'Višina',
+		height		: 'Višina',
 		lockRatio	: 'Zakleni razmerje',
+		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Ponastavi velikost',
-		border	: 'Obroba',
-		hSpace	: 'Vodoravni razmik',
-		vSpace	: 'Navpični razmik',
+		border		: 'Obroba',
+		hSpace		: 'Vodoravni razmik',
+		vSpace		: 'Navpični razmik',
 		align		: 'Poravnava',
 		alignLeft	: 'Levo',
 		alignRight	: 'Desno',
-		preview	: 'Predogled',
 		alertUrl	: 'Vnesite URL slike',
-		linkTab	: 'Povezava',
-		button2Img	: 'Do you want to transform the selected image button on a simple image?', // MISSING
-		img2Button	: 'Do you want to transform the selected image on a image button?', // MISSING
-		urlMissing : 'Image source URL is missing.' // MISSING
+		linkTab		: 'Povezava',
+		button2Img	: 'Želiš pretvoriti izbrani gumb s sliko v preprosto sliko?',
+		img2Button	: 'Želiš pretvoriti izbrano sliko v gumb s sliko?',
+		urlMissing	: 'Manjka vir (URL) slike.',
+		validateWidth	: 'Width must be a whole number.', // MISSING
+		validateHeight	: 'Height must be a whole number.', // MISSING
+		validateBorder	: 'Border must be a whole number.', // MISSING
+		validateHSpace	: 'HSpace must be a whole number.', // MISSING
+		validateVSpace	: 'VSpace must be a whole number.' // MISSING
 	},
 
 	// Flash Dialog
 	flash :
 	{
 		properties		: 'Lastnosti Flash',
-		propertiesTab	: 'Properties', // MISSING
-		title		: 'Lastnosti Flash',
-		chkPlay		: 'Samodejno predvajaj',
-		chkLoop		: 'Ponavljanje',
-		chkMenu		: 'Omogoči Flash Meni',
-		chkFull		: 'Allow Fullscreen', // MISSING
- 		scale		: 'Povečava',
+		propertiesTab	: 'Lastnosti',
+		title			: 'Lastnosti Flash',
+		chkPlay			: 'Samodejno predvajaj',
+		chkLoop			: 'Ponavljanje',
+		chkMenu			: 'Omogoči Flash Meni',
+		chkFull			: 'Dovoli celozaslonski način',
+ 		scale			: 'Povečava',
 		scaleAll		: 'Pokaži vse',
 		scaleNoBorder	: 'Brez obrobe',
 		scaleFit		: 'Natančno prileganje',
-		access			: 'Script Access', // MISSING
-		accessAlways	: 'Always', // MISSING
-		accessSameDomain	: 'Same domain', // MISSING
-		accessNever	: 'Never', // MISSING
-		align		: 'Poravnava',
-		alignLeft	: 'Levo',
-		alignAbsBottom: 'Popolnoma na dno',
-		alignAbsMiddle: 'Popolnoma v sredino',
+		access			: 'Dostop skript',
+		accessAlways	: 'Vedno',
+		accessSameDomain: 'Samo ista domena',
+		accessNever		: 'Nikoli',
+		align			: 'Poravnava',
+		alignLeft		: 'Levo',
+		alignAbsBottom	: 'Popolnoma na dno',
+		alignAbsMiddle	: 'Popolnoma v sredino',
 		alignBaseline	: 'Na osnovno črto',
-		alignBottom	: 'Na dno',
-		alignMiddle	: 'V sredino',
-		alignRight	: 'Desno',
+		alignBottom		: 'Na dno',
+		alignMiddle		: 'V sredino',
+		alignRight		: 'Desno',
 		alignTextTop	: 'Besedilo na vrh',
-		alignTop	: 'Na vrh',
-		quality		: 'Quality', // MISSING
-		qualityBest		 : 'Best', // MISSING
-		qualityHigh		 : 'High', // MISSING
-		qualityAutoHigh	 : 'Auto High', // MISSING
-		qualityMedium	 : 'Medium', // MISSING
-		qualityAutoLow	 : 'Auto Low', // MISSING
-		qualityLow		 : 'Low', // MISSING
-		windowModeWindow	 : 'Window', // MISSING
-		windowModeOpaque	 : 'Opaque', // MISSING
-		windowModeTransparent	 : 'Transparent', // MISSING
-		windowMode	: 'Window mode', // MISSING
-		flashvars	: 'Variables for Flash', // MISSING
-		bgcolor	: 'Barva ozadja',
-		width	: 'Širina',
-		height	: 'Višina',
-		hSpace	: 'Vodoravni razmik',
-		vSpace	: 'Navpični razmik',
-		validateSrc : 'Vnesite URL povezave',
-		validateWidth : 'Width must be a number.', // MISSING
-		validateHeight : 'Height must be a number.', // MISSING
-		validateHSpace : 'HSpace must be a number.', // MISSING
-		validateVSpace : 'VSpace must be a number.' // MISSING
+		alignTop		: 'Na vrh',
+		quality			: 'Kakovost',
+		qualityBest		: 'Najvišja',
+		qualityHigh		: 'Visoka',
+		qualityAutoHigh	: 'Samodejno visoka',
+		qualityMedium	: 'Srednja',
+		qualityAutoLow	: 'Samodejno nizka',
+		qualityLow		: 'Nizka',
+		windowModeWindow: 'Okno',
+		windowModeOpaque: 'Motno',
+		windowModeTransparent : 'Prosojno',
+		windowMode		: 'Vrsta okna',
+		flashvars		: 'Spremenljivke za Flash',
+		bgcolor			: 'Barva ozadja',
+		width			: 'Širina',
+		height			: 'Višina',
+		hSpace			: 'Vodoravni razmik',
+		vSpace			: 'Navpični razmik',
+		validateSrc		: 'Vnesite URL povezave',
+		validateWidth	: 'Širina mora biti število.',
+		validateHeight	: 'Višina mora biti število.',
+		validateHSpace	: 'Vodoravni razmik mora biti število.',
+		validateVSpace	: 'Navpični razmik mora biti število.'
 	},
 
 	// Speller Pages Dialog
 	spellCheck :
 	{
 		toolbar			: 'Preveri črkovanje',
-		title			: 'Spell Check', // MISSING
-		notAvailable	: 'Sorry, but service is unavailable now.', // MISSING
-		errorLoading	: 'Error loading application service host: %s.', // MISSING
+		title			: 'Črkovalnik',
+		notAvailable	: 'Oprostite, storitev trenutno ni dosegljiva.',
+		errorLoading	: 'Napaka pri nalaganju storitve programa na naslovu %s.',
 		notInDic		: 'Ni v slovarju',
 		changeTo		: 'Spremeni v',
 		btnIgnore		: 'Prezri',
@@ -472,25 +506,27 @@ CKEDITOR.lang['sl'] =
 	smiley :
 	{
 		toolbar	: 'Smeško',
-		title	: 'Vstavi smeška'
+		title	: 'Vstavi smeška',
+		options : 'Smiley Options' // MISSING
 	},
 
 	elementsPath :
 	{
-		eleTitle : '%1 element' // MISSING
+		eleLabel : 'Elements path', // MISSING
+		eleTitle : '%1 element'
 	},
 
-	numberedlist : 'Oštevilčen seznam',
-	bulletedlist : 'Označen seznam',
-	indent : 'Povečaj zamik',
-	outdent : 'Zmanjšaj zamik',
+	numberedlist	: 'Oštevilčen seznam',
+	bulletedlist	: 'Označen seznam',
+	indent			: 'Povečaj zamik',
+	outdent			: 'Zmanjšaj zamik',
 
 	justify :
 	{
-		left : 'Leva poravnava',
-		center : 'Sredinska poravnava',
-		right : 'Desna poravnava',
-		block : 'Obojestranska poravnava'
+		left	: 'Leva poravnava',
+		center	: 'Sredinska poravnava',
+		right	: 'Desna poravnava',
+		block	: 'Obojestranska poravnava'
 	},
 
 	blockquote : 'Citat',
@@ -498,64 +534,63 @@ CKEDITOR.lang['sl'] =
 	clipboard :
 	{
 		title		: 'Prilepi',
-		cutError	: 'Varnostne nastavitve brskalnika ne dopuščajo samodejnega izrezovanja. Uporabite kombinacijo tipk na tipkovnici (Ctrl+X).',
-		copyError	: 'Varnostne nastavitve brskalnika ne dopuščajo samodejnega kopiranja. Uporabite kombinacijo tipk na tipkovnici (Ctrl+C).',
-		pasteMsg	: 'Prosim prilepite v sleči okvir s pomočjo tipkovnice (<STRONG>Ctrl+V</STRONG>) in pritisnite <STRONG>V redu</STRONG>.',
-		securityMsg	: 'Zaradi varnostnih nastavitev vašega brskalnika urejevalnik ne more neposredno dostopati do odložišča. Vsebino odložišča ponovno prilepite v to okno.'
+		cutError	: 'Varnostne nastavitve brskalnika ne dopuščajo samodejnega izrezovanja. Uporabite kombinacijo tipk na tipkovnici (Ctrl/Cmd+X).',
+		copyError	: 'Varnostne nastavitve brskalnika ne dopuščajo samodejnega kopiranja. Uporabite kombinacijo tipk na tipkovnici (Ctrl/Cmd+C).',
+		pasteMsg	: 'Prosim prilepite v sleči okvir s pomočjo tipkovnice (<STRONG>Ctrl/Cmd+V</STRONG>) in pritisnite <STRONG>V redu</STRONG>.',
+		securityMsg	: 'Zaradi varnostnih nastavitev vašega brskalnika urejevalnik ne more neposredno dostopati do odložišča. Vsebino odložišča ponovno prilepite v to okno.',
+		pasteArea	: 'Paste Area' // MISSING
 	},
 
 	pastefromword :
 	{
-		confirmCleanup : 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
-		toolbar : 'Prilepi iz Worda',
-		title : 'Prilepi iz Worda',
-		error : 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		confirmCleanup	: 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
+		toolbar			: 'Prilepi iz Worda',
+		title			: 'Prilepi iz Worda',
+		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
 	},
 
 	pasteText :
 	{
-		button : 'Prilepi kot golo besedilo',
-		title : 'Prilepi kot golo besedilo'
+		button	: 'Prilepi kot golo besedilo',
+		title	: 'Prilepi kot golo besedilo'
 	},
 
 	templates :
 	{
-		button : 'Predloge',
-		title : 'Vsebinske predloge',
-		insertOption: 'Zamenjaj trenutno vsebino',
-		selectPromptMsg: 'Izberite predlogo, ki jo želite odpreti v urejevalniku<br>(trenutna vsebina bo izgubljena):',
-		emptyListMsg : '(Ni pripravljenih predlog)'
+		button			: 'Predloge',
+		title			: 'Vsebinske predloge',
+		options : 'Template Options', // MISSING
+		insertOption	: 'Zamenjaj trenutno vsebino',
+		selectPromptMsg	: 'Izberite predlogo, ki jo želite odpreti v urejevalniku<br>(trenutna vsebina bo izgubljena):',
+		emptyListMsg	: '(Ni pripravljenih predlog)'
 	},
 
 	showBlocks : 'Prikaži ograde',
 
 	stylesCombo :
 	{
-		label : 'Slog',
-		voiceLabel : 'Styles', // MISSING
-		panelVoiceLabel : 'Select a style', // MISSING
-		panelTitle1 : 'Block Styles', // MISSING
-		panelTitle2 : 'Inline Styles', // MISSING
-		panelTitle3 : 'Object Styles' // MISSING
+		label		: 'Slog',
+		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle1	: 'Slogi odstavkov',
+		panelTitle2	: 'Slogi besedila',
+		panelTitle3	: 'Slogi objektov'
 	},
 
 	format :
 	{
-		label : 'Oblika',
-		voiceLabel : 'Format', // MISSING
-		panelTitle : 'Oblika',
-		panelVoiceLabel : 'Select a paragraph format', // MISSING
+		label		: 'Oblika',
+		panelTitle	: 'Oblika',
 
-		tag_p : 'Navaden',
-		tag_pre : 'Oblikovan',
-		tag_address : 'Napis',
-		tag_h1 : 'Naslov 1',
-		tag_h2 : 'Naslov 2',
-		tag_h3 : 'Naslov 3',
-		tag_h4 : 'Naslov 4',
-		tag_h5 : 'Naslov 5',
-		tag_h6 : 'Naslov 6',
-		tag_div : 'Normal (DIV)' // MISSING
+		tag_p		: 'Navaden',
+		tag_pre		: 'Oblikovan',
+		tag_address	: 'Napis',
+		tag_h1		: 'Naslov 1',
+		tag_h2		: 'Naslov 2',
+		tag_h3		: 'Naslov 3',
+		tag_h4		: 'Naslov 4',
+		tag_h5		: 'Naslov 5',
+		tag_h6		: 'Naslov 6',
+		tag_div		: 'Navaden (DIV)'
 	},
 
 	div :
@@ -577,26 +612,25 @@ CKEDITOR.lang['sl'] =
 
 	font :
 	{
-		label : 'Pisava',
-		voiceLabel : 'Font', // MISSING
-		panelTitle : 'Pisava',
-		panelVoiceLabel : 'Select a font' // MISSING
+		label		: 'Pisava',
+		voiceLabel	: 'Pisava',
+		panelTitle	: 'Pisava'
 	},
 
 	fontSize :
 	{
-		label : 'Velikost',
-		voiceLabel : 'Font Size', // MISSING
-		panelTitle : 'Velikost',
-		panelVoiceLabel : 'Select a font size' // MISSING
+		label		: 'Velikost',
+		voiceLabel	: 'Velikost',
+		panelTitle	: 'Velikost'
 	},
 
 	colorButton :
 	{
-		textColorTitle : 'Barva besedila',
-		bgColorTitle : 'Barva ozadja',
-		auto : 'Samodejno',
-		more : 'Več barv...'
+		textColorTitle	: 'Barva besedila',
+		bgColorTitle	: 'Barva ozadja',
+		panelTitle		: 'Colors', // MISSING
+		auto			: 'Samodejno',
+		more			: 'Več barv...'
 	},
 
 	colors :
@@ -645,53 +679,69 @@ CKEDITOR.lang['sl'] =
 
 	scayt :
 	{
-		title : 'Spell Check As You Type', // MISSING
-		enable : 'Enable SCAYT', // MISSING
-		disable : 'Disable SCAYT', // MISSING
-		about : 'About SCAYT', // MISSING
-		toggle : 'Toggle SCAYT', // MISSING
-		options : 'Options', // MISSING
-		langs : 'Languages', // MISSING
-		moreSuggestions : 'More suggestions', // MISSING
-		ignore : 'Ignore', // MISSING
-		ignoreAll : 'Ignore All', // MISSING
-		addWord : 'Add Word', // MISSING
-		emptyDic : 'Dictionary name should not be empty.', // MISSING
-		optionsTab : 'Options', // MISSING
-		languagesTab : 'Languages', // MISSING
-		dictionariesTab : 'Dictionaries', // MISSING
-		aboutTab : 'About' // MISSING
+		title			: 'Črkovanje med tipkanjem',
+		opera_title		: 'Not supported by Opera', // MISSING
+		enable			: 'Omogoči SCAYT',
+		disable			: 'Onemogoči SCAYT',
+		about			: 'O storitvi SCAYT',
+		toggle			: 'Preklopi SCAYT',
+		options			: 'Možnosti',
+		langs			: 'Jeziki',
+		moreSuggestions	: 'Več predlogov',
+		ignore			: 'Prezri',
+		ignoreAll		: 'Prezri vse',
+		addWord			: 'Dodaj besedo',
+		emptyDic		: 'Ime slovarja ne more biti prazno.',
+
+		optionsTab		: 'Možnosti',
+		allCaps			: 'Ignore All-Caps Words', // MISSING
+		ignoreDomainNames : 'Ignore Domain Names', // MISSING
+		mixedCase		: 'Ignore Words with Mixed Case', // MISSING
+		mixedWithDigits	: 'Ignore Words with Numbers', // MISSING
+
+		languagesTab	: 'Jeziki',
+
+		dictionariesTab	: 'Slovarji',
+		dic_field_name	: 'Dictionary name', // MISSING
+		dic_create		: 'Create', // MISSING
+		dic_restore		: 'Restore', // MISSING
+		dic_delete		: 'Delete', // MISSING
+		dic_rename		: 'Rename', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type it\'s name and click the Restore button.', // MISSING
+
+		aboutTab		: 'O storitvi'
 	},
 
 	about :
 	{
-		title : 'About CKEditor', // MISSING
-		dlgTitle : 'About CKEditor', // MISSING
-		moreInfo : 'For licensing information please visit our web site:', // MISSING
-		copy : 'Copyright &copy; $1. All rights reserved.' // MISSING
+		title		: 'O programu CKEditor',
+		dlgTitle	: 'O programu CKEditor',
+		moreInfo	: 'Za informacijo o licenci prostim obiščite našo spletno stran:',
+		copy		: 'Copyright &copy; $1. Vse pravice pridržane.'
 	},
 
-	maximize : 'Maximize', // MISSING
-	minimize : 'Minimize', // MISSING
+	maximize : 'Maksimiraj',
+	minimize : 'Minimiraj',
 
 	fakeobjects :
 	{
-		anchor : 'Anchor', // MISSING
-		flash : 'Flash Animation', // MISSING
-		div : 'Page Break', // MISSING
-		unknown : 'Unknown Object' // MISSING
+		anchor	: 'Sidro',
+		flash	: 'Flash animacija',
+		div		: 'Prelom strani',
+		unknown	: 'Neznan objekt'
 	},
 
-	resize : 'Drag to resize', // MISSING
+	resize : 'Potegni za spremembo velikosti',
 
 	colordialog :
 	{
-		title : 'Select color', // MISSING
-		highlight : 'Highlight', // MISSING
-		selected : 'Selected', // MISSING
-		clear : 'Clear' // MISSING
+		title		: 'Izberi barvo',
+		options	:	'Color Options', // MISSING
+		highlight	: 'Poudarjeno',
+		selected	: 'Izbrano',
+		clear		: 'Počisti'
 	},
 
-	toolbarCollapse : 'Collapse Toolbar', // MISSING
-	toolbarExpand : 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Collapse Toolbar', // MISSING
+	toolbarExpand	: 'Expand Toolbar' // MISSING
 };
